@@ -51,7 +51,7 @@ headers = {"Content-Type": "application/json"}
     "-s",
     "--map-to-original-source",
     is_flag=True,
-    default=False,
+    default=None,
     required=False,
     help="Map the analyses results to the original source code, instead of the instrumented one. "
     "This is meant to be used with Scribble.",
@@ -62,26 +62,13 @@ headers = {"Content-Type": "application/json"}
     default=False,
     help="Outputs the data to be sent to the FaaS API without making the request.",
 )
-@click.option(
-    "--api-key",
-    type=click.STRING,
-    default=None,
-    help="API key, can be created on the FaaS Dashboard. ",
-    hidden=True,
-)
 @click.option(
     "-k",
     "--key",
     type=click.STRING,
     default=None,
     help="API key, can be created on the FaaS Dashboard. ",
-)
-@click.option(
-    "--refresh-token",
-    type=click.STRING,
-    default=None,
-    help="Refresh Token, can be created on the FaaS Dashboard. ",
-    hidden=True,
+    envvar="FUZZ_API_KEY",
 )
 @click.option(
     "-p",
@@ -107,9 +94,7 @@ def fuzz_run(
     more_addresses: str,
     corpus_target: str,
     dry_run,
-    api_key,
     key,
-    refresh_token,
     map_to_original_source,
     project,
     truffle_path: Optional[str],
@@ -118,18 +103,6 @@ def fuzz_run(
     analyze_config = ctx.get("analyze", {}) or {}
     fuzz_config = ctx.get("fuzz", {}) or {}
 
-    if fuzz_config.get("api_key") or api_key:
-        LOGGER.warning(
-            "The --api-key parameter and 'api_key' configuration file option value have been"
-            " deprecated. You should use the --key and 'key' options instead."
-        )
-
-    if fuzz_config.get("refresh_token") or refresh_token:
-        LOGGER.warning(
-            "The --refresh-token parameter and 'refresh_token' configuration file option have been"
-            " deprecated. You should use the --key and 'key' options instead."
-        )
-
     options = FuzzingOptions.from_config(
         fuzz_config,
         ide=ide,
@@ -139,7 +112,7 @@ def fuzz_run(
         map_to_original_source=map_to_original_source,
         corpus_target=corpus_target,
         dry_run=dry_run,
-        key=key or api_key or refresh_token,
+        key=key,
         project=project,
         truffle_executable_path=truffle_path,
     )
@@ -156,8 +129,7 @@ def fuzz_run(
             targets=options.target,
             build_dir=options.build_directory,
             sources_dir=options.sources_directory,
-            map_to_original_source=map_to_original_source
-            or options.map_to_original_source,
+            map_to_original_source=options.map_to_original_source,
             remappings=analyze_config.get("remappings", []),
             solc_version=analyze_config.get("solc-version", []),
             solc_path=None,
@@ -223,6 +195,8 @@ def submit_campaign(
         campaign_id = faas_client.create_faas_campaign(
             campaign_data=artifacts, seed_state=seed_state
         )
+        if options.dry_run:
+            return
         click.echo(
             "You can view campaign here: "
             + options.faas_url
